# -*- coding:utf-8 -*-
# !/usr/bin/env python

import requests
import json
import pandas as pd
from datetime import datetime, time
from expyhist_crawler.setting import USER_AGENT, APP_DF, SLEEP_TIME
import time


class AppRankScrapy:

    def __init__(self):

        self.rank_url = "https://api.qimai.cn/app/rank"
        self.appinfo_url = "https://api.qimai.cn/app/appinfo"

        self.headers = {
            "User-Agent": USER_AGENT,
            "referer": "https://www.qimai.cn/",
            "origin": "https://www.qimai.cn"
        }

    # 获取appid对应的rank
    def get_rank(self, app_id: str, analysis: str) -> pd.DataFrame:
        try:
            params = {
                "analysis": analysis,
                "appid": app_id,
                "country": "cn",
                "brand": "free",
                "day": "0",
                "appRankShow": "1",
                "subclass": "all",
                "simple": "1",
                "type": "1",
                "rankEchartType": "0",
                "rankType": "day"
            }
            r = requests.get(url=self.rank_url, params=params, headers=self.headers)
            time.sleep(SLEEP_TIME)
            # rank
            rank = json.loads(r.text)["realTimeRank"][1][1]["ranking"]
            special_rank = json.loads(r.text)["realTimeRank"][1][2]["ranking"]
            rank_df = pd.DataFrame(
                dict(app_id=[app_id], rank=[rank], special_rank=[special_rank],
                     create_time=[datetime.now().strftime("%Y-%m-%d %H:%M:%S")])
            )
        except Exception as e:
            print(e)
            rank_df = pd.DataFrame(
                dict(app_id=[app_id], rank=["-"], special_rank=["-"],
                     create_time=[datetime.now().strftime("%Y-%m-%d %H:%M:%S")])
            )
            print("appid:" + app_id + " can't get rank")

        return rank_df

    # 获取appid对应的appname
    def get_appinfo(self, app_id: str, analysis: str) -> pd.DataFrame:

        try:
            params = {
                "analysis": analysis,
                "appid": app_id,
                "country": "cn"
            }
            r = requests.get(url=self.appinfo_url, params=params, headers=self.headers)
            time.sleep(SLEEP_TIME)
            # appname
            app_name = json.loads(r.text)["appInfo"]["appname"]
            appinfo_df = pd.DataFrame(
                dict(app_id=[app_id], app_name=[app_name], create_time=[datetime.now().strftime("%Y-%m-%d %H:%M:%S")])
            )
        except Exception as e:
            print(e)
            appinfo_df = pd.DataFrame(
                dict(app_id=[app_id], app_name=["-"], create_time=[datetime.now().strftime("%Y-%m-%d %H:%M:%S")])
            )
            print("appid:" + app_id + " can't get appinfo")

        return appinfo_df

    # 合并rank和appname
    def get_result(self, *args) -> pd.DataFrame:
        # 遍历appid和analysisi参数
        rank_df = pd.concat([self.get_rank(app_id=i, analysis=j)
                             for i, j in zip(APP_DF["app_id"].to_list(), APP_DF["rank_analysis"].to_list())])

        appinfo_df = pd.concat([self.get_appinfo(app_id=i, analysis=j)
                                for i, j in zip(APP_DF["app_id"].to_list(), APP_DF["appinfo_analysis"].to_list())])
        # 将两个df结果合并成一个df
        if len(args) == 2:
            result_df = pd.merge(args[0], args[1], on="app_id", how="left")
        else:
            result_df = pd.merge(appinfo_df, rank_df[["app_id", "rank", "special_rank"]], on="app_id", how="left")

        return result_df


if __name__ == "__main__":
    test = AppRankScrapy()
    print(test.get_result())



# -*- coding:utf-8 -*-
# !/usr/bin/env python


import time
import random
import sqlite3
from datetime import datetime
from functools import wraps
import pandas as pd


def save_decorator(table_name, database_path, if_exists):
    def decorator(func):
        db_create_time = datetime.strftime(datetime.now(), "%Y-%m-%d %H:%M:%S")

        @wraps(func)
        def wrapper(*args, **kwargs):
            print("=" * 20 + "\n" + func.__name__ + " start saving,time:{}".format(db_create_time))
            print(database_path)
            # connect sqlite3
            conn = sqlite3.connect(database_path)
            try:
                if type(func(*args, **kwargs)) == pd.DataFrame:
                    # get df of copy
                    df = func(*args, **kwargs).copy()
                    df["db_create_time"] = db_create_time
                    # write data to database
                    df.to_sql(name=table_name, con=conn, if_exists=if_exists, index=False)
                    print("save success")
                    time.sleep(random.random() * 10 / 5)
                else:
                    print("result is not DataFrame")
            except Exception as e:
                print(e)
            finally:
                # close connection of database
                conn.close()

        return wrapper

    return decorator


if __name__ == "__main__":
    pass



# -*- coding:utf-8 -*-
# !/usr/bin/env python

import pandas as pd
import os
import random

from random_user_agent.user_agent import UserAgent
from random_user_agent.params import SoftwareName, OperatingSystem

from configparser import ConfigParser

# dict to df
df_dict = dict(
    app_name=["粉象生活", "蜜源", "骑士卡", "花生日记", "好省", "福袋生活"],
    app_id=["1383296825", "1262351972", "1436462010", "1390240947", "1332598333", "1463740455"],
    rank_analysis=[
        "dSB1TixkdUh9SldKdQ5cCitwf1BpZ0hDaQIFUz1vVAlXWzdccBMfUUBAFxZWVg90FVAABAMBBQUGAFwODSQXBw==",
        "dSB1TixkdUh9WmlJdR5iQCtgVRhpZ0hDaQIFUz1vVAlXWzdccBMfUUBAFxZWVg90FVAABAMBBQYCClQBCCQXBw==",
        "dSB1TixkdUh+dH0CdiBuQSlwcxZpZ0hDaQIFUz1vVAlXWzdccBMfUUBAFxZWVg90FVAABAMBBQYDAFQCASQXBw==",
        "dSB1TixkdUh9SltHdQ5mTytgZ1JpZ0hDaQIFUz1vVAlXWzdccBMfUUBAFxZWVg90FVAABAMBBQYFAFwHDCQXBw==",
        "dSB1TixkdUh9Sn1JdjBcDClOextpZ0hDaQIFUz1vVAlXWzdccBMfUUBAFxZWVg90FVAABAMBBQAJCVUFDSQXBw==",
        "dSB1TixkdUh+dGlKdh5mTypwY1BpZ0hDaQIFUz1vVAlXWzdccBMfUUBAFxZWVg90FVAABQQIBQkBD1ICDCQXBw=="
    ],
    appinfo_analysis=[
        "dTB5AixKeQV+WldJdjN5TSQXGQBAQB9RQEBZVgJYeEcMD1UBCAYGBQAEDSQUCQ==",
        "dTB9BCxafQF9ZFsDdQl5TSQXGQBAQB9RQEBZVgJYeEcMD1YGAwAIAAUHCyQUCQ==",
        "dTBlTC9aYQJ9WnFIdSN5TSQXGQBAQB9RQEBZVgJYeEcMD1UBCAYABQICCiQUCQ==",
        "dTB5Ayx0eQB9dFsAdlZ5TSQXGQBAQB9RQEBZVgJYeEcMD1QAAwYFCQgEASQUCQ==",
        "dTB5TCxaZQV/dH1KdVZ5TSQXGQBAQB9RQEBZVgJYeEcFBlUDAQQIBAYADVJ3G1U=",
        "dTBlBCxKUwB9dGEBdjN5TSQXGQBAQB9RQEBZVgJYeEcFBlQECAUIAAIFAFd3G1U="
    ]
)
APP_DF = pd.DataFrame(df_dict)

# random user_agent
software_names = [SoftwareName.CHROME.value]
operating_systems = [OperatingSystem.WINDOWS.value, OperatingSystem.LINUX.value]
user_agent_rotator = UserAgent(software_names=software_names, operating_systems=operating_systems, limit=100)
USER_AGENT = user_agent_rotator.get_random_user_agent()


# database path
def set_database_path(database_name):
    return os.path.join(os.path.dirname(__file__), "db/{}".format(database_name))


# sleep time
SLEEP_TIME = random.random() * 10 / 2

# email and umeng account


if "config.ini" in os.listdir(os.path.dirname(os.path.dirname(os.path.realpath(__file__)))):
    cfg = ConfigParser()
    cfg.read(os.path.dirname(os.path.dirname(os.path.realpath(__file__))) + r"\config.ini", encoding="utf-8-sig")
    USERNAME = cfg.get("email_account", "user_name")
    PASSWORD = cfg.get("email_account", "pass_word")
    APIKEY = cfg.get("umeng_api_info", "api_key")
    APISECURITY = cfg.get("umeng_api_info", "api_security")
    APPKEYS = [cfg.get("umeng_api_info", "ios_app_keys"), cfg.get("umeng_api_info", "android_app_keys")]
else:
    print("Not Exists config.ini")

# chromedrive
CHROMEDRIVER_PATH = os.path.join(os.path.dirname(__file__),
                                 r"file/{}".format("chromedriver.exe" if os.name == "nt" else "chromedriver"))



# -*- coding: utf-8 -*-
#!/usr/bin/env python

"""
Created on 2016-12-26

@author: Alibaba Open Platform

"""

from aop.api.base import FileItem, BaseApi
from aop.api.common import *
from aop.api.biz import *


# -*- coding: utf-8 -*-
from aop.api.base import BaseApi

class UmengUappGetLaunchesByChannelOrVersionRequest(BaseApi):
    """根据渠道或版本条件，获取指定App某个时间范围内的启动次数

    References
    ----------
    https://open.1688.com/api/api.htm?ns=com.umeng.uapp&n=umeng.uapp.getLaunchesByChannelOrVersion&v=1&cat=default

    """

    def __init__(self, domain=None):
        BaseApi.__init__(self, domain)
        self.appkey = None
        self.startDate = None
        self.endDate = None
        self.periodType = None
        self.channels = None
        self.versions = None

    def get_api_uri(self):
        return '1/com.umeng.uapp/umeng.uapp.getLaunchesByChannelOrVersion'

    def get_required_params(self):
        return ['appkey', 'startDate', 'endDate', 'periodType']

    def get_multipart_params(self):
        return []

    def need_sign(self):
        return True

    def need_timestamp(self):
        return False

    def need_auth(self):
        return False

    def is_inner_api(self):
        return False



# -*- coding: utf-8 -*-
from aop.api.base import BaseApi

class UmengUappGetAllAppDataRequest(BaseApi):
    """获取当前用户所有App昨日和今日的基础统计数据（活跃用户数，新增用户数，启动次数，总用户数）

    References
    ----------
    https://open.1688.com/api/api.htm?ns=com.umeng.uapp&n=umeng.uapp.getAllAppData&v=1&cat=default

    """

    def __init__(self, domain=None):
        BaseApi.__init__(self, domain)

    def get_api_uri(self):
        return '1/com.umeng.uapp/umeng.uapp.getAllAppData'

    def get_required_params(self):
        return []

    def get_multipart_params(self):
        return []

    def need_sign(self):
        return True

    def need_timestamp(self):
        return False

    def need_auth(self):
        return False

    def is_inner_api(self):
        return False



# -*- coding:utf-8 -*-
# !/usr/bin/env python

import sys
import os
import re

from smtplib import SMTP_SSL as SMTP  # this invokes the secure SMTP protocol (port 465, uses SSL)
from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText
from email.mime.image import MIMEImage
from email.mime.application import MIMEApplication

from expyhist_crawler.setting import USERNAME, PASSWORD


class AliyunEmail:

    def __init__(self, destination: list = None, subject: str = "Sent from Python"):

        self.msg = MIMEMultipart()

        self.SMTPserver = "smtp.mxhichina.com"
        self.sender = "yanghua@fenxianglife.com"

        if destination is None:
            self.destination = ["yanghua@fenxianglife.com"]
        elif isinstance(destination, list):
            self.destination = destination
        else:
            sys.exit("type of destination is wrong")

        self.subject = subject

        self.msg["Subject"] = self.subject
        self.msg["From"] = self.sender  # some SMTP servers will do this automatically, not all

    def send_email(self, text_content: str = "Test", text_subtype: str = "plain"):
        try:
            # text content
            msg_text = MIMEText(text_content, text_subtype)
            self.msg.attach(msg_text)

            # attchment
            msg_application = MIMEApplication(open("C:/Users/YangHua/Desktop/每天数据-终.xlsx", "rb").read())
            msg_application.add_header("Content-Disposition", "attachment", filename="test.csv")
            self.msg.attach(msg_application)

            conn = SMTP(self.SMTPserver)
            conn.set_debuglevel(True)
            conn.login(USERNAME, PASSWORD)
            try:
                conn.sendmail(self.sender, self.destination, self.msg.as_string())
            finally:
                conn.quit()
        except Exception as e:
            print(e)
            sys.exit("mail failed; %s" % "CUSTOM_ERROR")  # give an error message


if __name__ == "__main__":
    AliyunEmail().send_email()



# -*- coding: utf-8 -*-
#!/usr/bin/env python

"""
Created on 2016-12-26

@author: Alibaba Open Platform

"""

# from aop.api.common.AuthGetTokenRequest import AuthGetTokenRequest
# from aop.api.common.AuthPostponeTokenRequest import AuthPostponeTokenRequest
from aop.api.common.GetServerTimestampRequest import GetServerTimestampRequest



# -*- coding:utf-8 -*-
# !/usr/bin/env python

import pandas as pd
from datetime import datetime, timedelta

import os
import sys
sys.path.append(os.path.abspath(".."))

import aop
import aop.api


if "config.ini" in os.listdir(os.path.dirname(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))):
    from expyhist_crawler.setting import APIKEY, APISECURITY, APPKEYS


class UMengScrapy:

    def __init__(self):

        # 设置网关域名
        aop.set_default_server('gateway.open.umeng.com')

        # 设置apiKey和apiSecurity
        aop.set_default_appinfo(APIKEY, APISECURITY)

        # 设置appkey
        self.appkeys = APPKEYS

    @staticmethod
    def get_durations(app_key: str, date: str) -> pd.DataFrame:

        # 构造Request和访问协议是否是https
        req = aop.api.UmengUappGetDurationsRequest()

        # 发起Api请求
        try:
            resp = req.get_response(None, appkey=app_key, date=date, statType="daily")
            df = pd.DataFrame.from_dict(resp["durationInfos"])
            return df
        except aop.ApiError as e:
            # Api网关返回的异常
            print(e)
        except aop.AopError as e:
            # 客户端Api网关请求前的异常
            print(e)
        except Exception as e:
            # 其它未知异常
            print(e)

    def get_durations_result(self, date: str) -> pd.DataFrame:
        try:
            df = pd.concat([self.get_durations(i, date) for i in self.appkeys])
            return df.groupby(["name", df.index])["value"].sum().reset_index().sort_values(by="level_1")
        except Exception as e:
            print(e)

    @staticmethod
    def get_monthly_active_user(app_key: str, start_date: str, end_date: str) -> pd.DataFrame:

        # 构造Request和访问协议是否是https
        req = aop.api.UmengUappGetActiveUsersRequest()

        # 发起Api请求
        try:
            resp = req.get_response(None, appkey=app_key, startDate=start_date, endDate=end_date, periodType="monthly")
            df = pd.DataFrame.from_dict(resp["activeUserInfo"])
            return df
        except aop.ApiError as e:
            # Api网关返回的异常
            print(e)
        except aop.AopError as e:
            # 客户端Api网关请求前的异常
            print(e)
        except Exception as e:
            # 其它未知异常
            print(e)

    def get_monthly_active_user_result(self, start_date: str, end_date: str) -> pd.DataFrame:
        try:
            df = pd.concat([self.get_monthly_active_user(i, start_date, end_date) for i in self.appkeys])
            return df.groupby("date")["value"].sum().reset_index()
        except Exception as e:
            print(e)

    @staticmethod
    def get_monthly_launches(app_key: str, start_date: str, end_date: str) -> pd.DataFrame:

        # 构造Request和访问协议是否是https
        req = aop.api.UmengUappGetLaunchesRequest()

        # 发起Api请求
        try:
            resp = req.get_response(None, appkey=app_key, startDate=start_date, endDate=end_date, periodType="monthly")
            df = pd.DataFrame.from_dict(resp["launchInfo"])
            return df
        except aop.ApiError as e:
            # Api网关返回的异常
            print(e)
        except aop.AopError as e:
            # 客户端Api网关请求前的异常
            print(e)
        except Exception as e:
            # 其它未知异常
            print(e)

    def get_monthly_launches_result(self, start_date: str, end_date: str):
        try:
            df = pd.concat([self.get_monthly_launches(i, start_date, end_date) for i in self.appkeys])
            return df.groupby("date")["value"].sum().reset_index()
        except Exception as e:
            print(e)


if __name__ == "__main__":
    # 当日时间的月份1号
    first_date = datetime.now().date().replace(day=1)
    # 当日时间的上个月份最后一天
    end_date = first_date - timedelta(days=1)
    # 当日时间的上个月份1号
    start_date = end_date.replace(day=1)

    print(UMengScrapy().get_durations_result(str(end_date)))
    print(UMengScrapy().get_monthly_active_user_result(str(start_date), str(end_date)))
    print(UMengScrapy().get_monthly_launches_result(str(start_date), str(end_date)))




from Crypto.Cipher import AES
from Crypto import Random

"""
AES对称加密算法
"""


def pad(s):
    return s + b"\0" * (AES.block_size - len(s) % AES.block_size)


def encrypt(message, key):
    message = pad(message)
    iv = Random.new().read(AES.block_size)
    cipher = AES.new(key, AES.MODE_CBC, iv)
    return iv + cipher.encrypt(message)


def decrypt(ciphertext, key):
    iv = ciphertext[:AES.block_size]
    cipher = AES.new(key, AES.MODE_CBC, iv)
    plaintext = cipher.decrypt(ciphertext[AES.block_size:])
    return plaintext.rstrip(b"\0")


def encrypt_file(file_name, key):
    with open(file_name, "rb") as fo:
        plaintext = fo.read()
    enc = encrypt(plaintext, key)
    with open(file_name + ".enc", "wb") as fo:
        fo.write(enc)


def decrypt_file(file_name, key):
    with open(file_name, "rb") as fo:
        ciphertext = fo.read()
    dec = decrypt(ciphertext, key)
    with open(file_name[:-4]+".test", "wb") as fo:
        fo.write(dec)



# -*- coding:utf-8 -*-
# !/usr/bin/env python


from expyhist_crawler.decorator import save_decorator
from expyhist_crawler.setting import set_database_path

from expyhist_crawler.crawler.app_rank_crawler import AppRankScrapy


@save_decorator("app_rank", set_database_path("crawler.db"), "append")
def app_rank():

    return AppRankScrapy().get_result()


if __name__ == "__main__":
    app_rank()



from aop.api.biz.UmengApptrackBackReportDataRequest import UmengApptrackBackReportDataRequest
from aop.api.biz.UmengApptrackGetActiveDetailDataRequest import UmengApptrackGetActiveDetailDataRequest
from aop.api.biz.UmengApptrackGetPayAnalysisDataRequest import UmengApptrackGetPayAnalysisDataRequest
from aop.api.biz.UmengApptrackGetOrderAnalysisDataRequest import UmengApptrackGetOrderAnalysisDataRequest
from aop.api.biz.UmengApptrackGetRegisterAnalysisDataRequest import UmengApptrackGetRegisterAnalysisDataRequest
from aop.api.biz.UmengApptrackGetMonitoringListRequest import UmengApptrackGetMonitoringListRequest
from aop.api.biz.UmengApptrackGetClickActiveDataRequest import UmengApptrackGetClickActiveDataRequest
from aop.api.biz.UmengApptrackGetStayTrendDataRequest import UmengApptrackGetStayTrendDataRequest
from aop.api.biz.UmengApptrackGetPlanListRequest import UmengApptrackGetPlanListRequest
from aop.api.biz.UmengApptrackGetMyEventDataRequest import UmengApptrackGetMyEventDataRequest
from aop.api.biz.UmengApptrackGetRegisterLoginDataRequest import UmengApptrackGetRegisterLoginDataRequest
from aop.api.biz.UmengUappCreateAppRequest import UmengUappCreateAppRequest
from aop.api.biz.UmengUappGetNewAccountsRequest import UmengUappGetNewAccountsRequest
from aop.api.biz.UmengUappGetActiveAccountsRequest import UmengUappGetActiveAccountsRequest
from aop.api.biz.UmengUappGetLaunchesByChannelOrVersionRequest import UmengUappGetLaunchesByChannelOrVersionRequest
from aop.api.biz.UmengUappEventCreateRequest import UmengUappEventCreateRequest
from aop.api.biz.UmengUappGetActiveUsersByChannelOrVersionRequest import UmengUappGetActiveUsersByChannelOrVersionRequest
from aop.api.biz.UmengUappGetNewUsersByChannelOrVersionRequest import UmengUappGetNewUsersByChannelOrVersionRequest
from aop.api.biz.UmengUappEventParamGetValueDurationListRequest import UmengUappEventParamGetValueDurationListRequest
from aop.api.biz.UmengUappGetTodayYesterdayDataRequest import UmengUappGetTodayYesterdayDataRequest
from aop.api.biz.UmengUappGetYesterdayDataRequest import UmengUappGetYesterdayDataRequest
from aop.api.biz.UmengUappGetTodayDataRequest import UmengUappGetTodayDataRequest
from aop.api.biz.UmengUappEventGetUniqueUsersRequest import UmengUappEventGetUniqueUsersRequest
from aop.api.biz.UmengUappGetAllAppDataRequest import UmengUappGetAllAppDataRequest
from aop.api.biz.UmengUappGetAppCountRequest import UmengUappGetAppCountRequest
from aop.api.biz.UmengUappGetChannelDataRequest import UmengUappGetChannelDataRequest
from aop.api.biz.UmengUappGetVersionDataRequest import UmengUappGetVersionDataRequest
from aop.api.biz.UmengUappEventParamGetDataRequest import UmengUappEventParamGetDataRequest
from aop.api.biz.UmengUappEventParamGetValueListRequest import UmengUappEventParamGetValueListRequest
from aop.api.biz.UmengUappEventGetDataRequest import UmengUappEventGetDataRequest
from aop.api.biz.UmengUappEventParamListRequest import UmengUappEventParamListRequest
from aop.api.biz.UmengUappEventListRequest import UmengUappEventListRequest
from aop.api.biz.UmengUappGetRetentionsRequest import UmengUappGetRetentionsRequest
from aop.api.biz.UmengUappGetDurationsRequest import UmengUappGetDurationsRequest
from aop.api.biz.UmengUappGetLaunchesRequest import UmengUappGetLaunchesRequest
from aop.api.biz.UmengUappGetActiveUsersRequest import UmengUappGetActiveUsersRequest
from aop.api.biz.UmengUappGetNewUsersRequest import UmengUappGetNewUsersRequest
from aop.api.biz.UmengUappGetDailyDataRequest import UmengUappGetDailyDataRequest
from aop.api.biz.UmengUappGetAppListRequest import UmengUappGetAppListRequest
from aop.api.biz.UmengUminiInitMultiLevelTreeRequest import UmengUminiInitMultiLevelTreeRequest
from aop.api.biz.UmengUminiGetMultiLevelTreeRequest import UmengUminiGetMultiLevelTreeRequest
from aop.api.biz.UmengUminiGetLandingPageListRequest import UmengUminiGetLandingPageListRequest
from aop.api.biz.UmengUminiGetShareUserListRequest import UmengUminiGetShareUserListRequest
from aop.api.biz.UmengUminiGetVisitPageListRequest import UmengUminiGetVisitPageListRequest
from aop.api.biz.UmengUminiEditPathDisplayNameRequest import UmengUminiEditPathDisplayNameRequest
from aop.api.biz.UmengUminiBatchCreateEventRequest import UmengUminiBatchCreateEventRequest
from aop.api.biz.UmengUminiEditMiniAppRequest import UmengUminiEditMiniAppRequest
from aop.api.biz.UmengUminiGetShareOverviewRequest import UmengUminiGetShareOverviewRequest
from aop.api.biz.UmengUminiGetSharePageOverviewRequest import UmengUminiGetSharePageOverviewRequest
from aop.api.biz.UmengUminiGetAllPropertyValueCountRequest import UmengUminiGetAllPropertyValueCountRequest
from aop.api.biz.UmengUminiGetEventOverviewRequest import UmengUminiGetEventOverviewRequest
from aop.api.biz.UmengUminiGetEventProvertyListRequest import UmengUminiGetEventProvertyListRequest
from aop.api.biz.UmengUminiGetEventListRequest import UmengUminiGetEventListRequest
from aop.api.biz.UmengUminiGetChannelOverviewRequest import UmengUminiGetChannelOverviewRequest
from aop.api.biz.UmengUminiGetCampaignOverviewRequest import UmengUminiGetCampaignOverviewRequest
from aop.api.biz.UmengUminiGetSceneOverviewRequest import UmengUminiGetSceneOverviewRequest
from aop.api.biz.UmengUminiGetAppListRequest import UmengUminiGetAppListRequest
from aop.api.biz.UmengUminiCreateMiniAppRequest import UmengUminiCreateMiniAppRequest
from aop.api.biz.UmengUminiGetOverviewRequest import UmengUminiGetOverviewRequest
from aop.api.biz.UmengUminiGetTotalUserRequest import UmengUminiGetTotalUserRequest



# -*- coding:utf-8 -*-
# !/usr/bin/env python

import requests
import re
import pandas as pd


def title_scrapy() -> pd.DataFrame:

    df = pd.DataFrame(
        dict(
            catg=["中间bar", "中间bar", "金象任务", "金象任务", "果园", "果园", "果园", "签到", "签到", "签到"],
            urls=["https://m.fenxianglife.com/fms/100004/552812/index.html",
                  "https://m.fenxianglife.com/fms/100004/3e0704/index.html",
                  "https://m.fenxianglife.com/fms/100004/bebf44/index.html",
                  "https://m.fenxianglife.com/fms/100004/8ceb00/index.html",
                  "https://m.fenxianglife.com/fms/100004/74a2e9/index.html",
                  "https://m.fenxianglife.com/fms/100004/5e7254/index.html",
                  "https://m.fenxianglife.com/fms/100004/0a7d50/index.html",
                  "https://m.fenxianglife.com/fms/100004/584d90/index.html",
                  "https://m.fenxianglife.com/fms/100004/e9aad0/index.html",
                  "https://m.fenxianglife.com/fms/100004/6f4eb4/index.html"]
        )
    )
    titles = []

    for i in df["urls"]:
        r = requests.get(url=i)
        r.encoding = "utf-8"
        title = re.findall(r"<title>(.*?)</title>", r.text)[0]
        titles.append(title)

    df["titles"] = titles

    return df


if __name__ == "__main__":
    pass



# -*- coding:utf-8 -*-
# !/usr/bin/env python

import os

import setuptools

with open(os.path.join(os.path.dirname(__file__), "README.md"), "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="expyhist_crawler",
    version="0.0.4",
    description="simply web crawler",
    author="Expyh",
    author_email="exceptionalyh@gmail.com",
    url="https://github.com/expyhist/expyhist_crawler",
    packages=setuptools.find_packages(exclude=("tests", "tests.*")),
    license="MIT",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        "requests",
        "pandas",
        "random_user_agent",
    ],
    package_data={"expyhist_crawler": ["db/*.db", "file/*"]}
)



# -*- coding: utf-8 -*-
from aop.api.base import BaseApi

class UmengUminiGetOverviewRequest(BaseApi):
    """获取应用概况数据：启动、活跃、新增、访次、次均停留时长、人均停留时长

    References
    ----------
    https://open.1688.com/api/api.htm?ns=com.umeng.umini&n=umeng.umini.getOverview&v=1&cat=default

    """

    def __init__(self, domain=None):
        BaseApi.__init__(self, domain)
        self.dataSourceId = None
        self.fromDate = None
        self.toDate = None
        self.timeUnit = None
        self.indicators = None
        self.pageIndex = None
        self.pageSize = None

    def get_api_uri(self):
        return '1/com.umeng.umini/umeng.umini.getOverview'

    def get_required_params(self):
        return ['dataSourceId', 'fromDate', 'toDate', 'timeUnit', 'indicators']

    def get_multipart_params(self):
        return []

    def need_sign(self):
        return True

    def need_timestamp(self):
        return False

    def need_auth(self):
        return True

    def is_inner_api(self):
        return False
